package com.ruoyi.project.training.bccnew.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.training.bccnew.mapper.TTsLjplanContentMapper;
import com.ruoyi.project.training.bccnew.domain.TTsLjplanContent;
import com.ruoyi.project.training.bccnew.service.ITTsLjplanContentService;

/**
 * 裂解培训内容Service业务层处理
 *
 * @author ssy
 * @date 2024-07-19
 */
@Service
public class TTsLjplanContentServiceImpl implements ITTsLjplanContentService
{
    @Autowired
    private TTsLjplanContentMapper tTsLjplanContentMapper;

    /**
     * 查询裂解培训内容
     *
     * @param id 裂解培训内容ID
     * @return 裂解培训内容
     */
    @Override
    public TTsLjplanContent selectTTsLjplanContentById(Long id)
    {
        return tTsLjplanContentMapper.selectTTsLjplanContentById(id);
    }

    /**
     * 查询裂解培训内容列表
     *
     * @param tTsLjplanContent 裂解培训内容
     * @return 裂解培训内容
     */
    @Override
    public List<TTsLjplanContent> selectTTsLjplanContentList(TTsLjplanContent tTsLjplanContent)
    {
        return tTsLjplanContentMapper.selectTTsLjplanContentList(tTsLjplanContent);
    }

    /**
     * 新增裂解培训内容
     *
     * @param tTsLjplanContent 裂解培训内容
     * @return 结果
     */
    @Override
    public int insertTTsLjplanContent(TTsLjplanContent tTsLjplanContent)
    {
        return tTsLjplanContentMapper.insertTTsLjplanContent(tTsLjplanContent);
    }

    /**
     * 修改裂解培训内容
     *
     * @param tTsLjplanContent 裂解培训内容
     * @return 结果
     */
    @Override
    public int updateTTsLjplanContent(TTsLjplanContent tTsLjplanContent)
    {
        return tTsLjplanContentMapper.updateTTsLjplanContent(tTsLjplanContent);
    }

    /**
     * 批量删除裂解培训内容
     *
     * @param ids 需要删除的裂解培训内容ID
     * @return 结果
     */
    @Override
    public int deleteTTsLjplanContentByIds(Long[] ids)
    {
        return tTsLjplanContentMapper.deleteTTsLjplanContentByIds(ids);
    }

    /**
     * 删除裂解培训内容信息
     *
     * @param id 裂解培训内容ID
     * @return 结果
     */
    @Override
    public int deleteTTsLjplanContentById(Long id)
    {
        return tTsLjplanContentMapper.deleteTTsLjplanContentById(id);
    }
}
