package com.ruoyi.project.training.bccnew.controller;

import java.util.List;

import com.ruoyi.project.training.bccnew.domain.TTsFlplanContent;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.training.bccnew.domain.TTsLjplanContent;
import com.ruoyi.project.training.bccnew.service.ITTsLjplanContentService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 裂解培训内容Controller
 *
 * @author ssy
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/bccnew/ljContent")
public class TTsLjplanContentController extends BaseController
{
    @Autowired
    private ITTsLjplanContentService tTsLjplanContentService;

    /**
     * 查询裂解培训内容列表
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:ljContent:list')")
    @GetMapping("/list")
    public AjaxResult list(TTsLjplanContent tTsLjplanContent)
    {
        return AjaxResult.success(tTsLjplanContentService.selectTTsLjplanContentList(tTsLjplanContent));
    }

    /**
     * 导出裂解培训内容列表
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:ljContent:export')")
    @Log(title = "裂解培训内容", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTsLjplanContent tTsLjplanContent)
    {
        List<TTsLjplanContent> list = tTsLjplanContentService.selectTTsLjplanContentList(tTsLjplanContent);
        ExcelUtil<TTsLjplanContent> util = new ExcelUtil<TTsLjplanContent>(TTsLjplanContent.class);
        return util.exportExcel(list, "ljContent");
    }

    /**
     * 获取裂解培训内容详细信息
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:ljContent:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tTsLjplanContentService.selectTTsLjplanContentById(id));
    }

    /**
     * 新增裂解培训内容
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:ljContent:add')")
    @Log(title = "裂解培训内容", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTsLjplanContent tTsLjplanContent)
    {
        return toAjax(tTsLjplanContentService.insertTTsLjplanContent(tTsLjplanContent));
    }

    /**
     * 修改裂解培训内容
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:ljContent:edit')")
    @Log(title = "裂解培训内容", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTsLjplanContent tTsLjplanContent)
    {
        return toAjax(tTsLjplanContentService.updateTTsLjplanContent(tTsLjplanContent));
    }

    /**
     * 删除裂解培训内容
     */
    //@PreAuthorize("@ss.hasPermi('bccnew:ljContent:remove')")
    @Log(title = "裂解培训内容", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tTsLjplanContentService.deleteTTsLjplanContentByIds(ids));
    }
}
